<?php

require_once('cache.php');

class Report extends ChallengeCacheTable
{
	static public function instance( $class = "Report", $table = 'report', &$cache = null )
	{
		return parent::instance( 'Report', 'report', $cache );
	}
	
	public function getWrapperClassName()
	{
		return 'ReportItem';
	}

}

?>